@@ -210,10 +210,10 @@ SSE_C_KEY = {
 SSE_KMS_KEY_ID = {
     'name': 'sse-kms-key-id',
     'help_text': (
-        'The AWS KMS key ID that should be used to server-side '
-        'encrypt the object in S3. Note that you should only '
-        'provide this parameter if KMS key ID is different the '
-        'default S3 master KMS key.'
+        'The customer-managed AWS Key Management Service (KMS) key ID that '
+        'should be used to server-side encrypt the object in S3. You should '
+        'only provide this parameter if you are using a customer managed '
+        'customer master key (CMK) and not the AWS managed KMS CMK.'
     )
 }
 
@@ -249,12 +249,13 @@ SSE_C_COPY_SOURCE_KEY = {
 
 STORAGE_CLASS = {'name': 'storage-class',
                  'choices': ['STANDARD', 'REDUCED_REDUNDANCY', 'STANDARD_IA',
-                             'ONEZONE_IA', 'INTELLIGENT_TIERING', 'GLACIER'],
+                             'ONEZONE_IA', 'INTELLIGENT_TIERING', 'GLACIER',
+                             'DEEP_ARCHIVE'],
                  'help_text': (
                      "The type of storage to use for the object. "
                      "Valid choices are: STANDARD | REDUCED_REDUNDANCY "
                      "| STANDARD_IA | ONEZONE_IA | INTELLIGENT_TIERING "
-                     "| GLACIER. "
+                     "| GLACIER | DEEP_ARCHIVE. "
                      "Defaults to 'STANDARD'")}
 
 
@@ -385,7 +386,7 @@ EXPECTED_SIZE = {'name': 'expected-size',
                      'This argument specifies the expected size of a stream '
                      'in terms of bytes. Note that this argument is needed '
                      'only when a stream is being uploaded to s3 and the size '
-                     'is larger than 5GB.  Failure to include this argument '
+                     'is larger than 50GB.  Failure to include this argument '
                      'under these conditions may result in a failed upload '
                      'due to too many parts in upload.')}
 
